========
EO-Forge
========

This package provides easy-to-use tools for reading and processing remote sensing data from 
Sentinel2, Landsat5, and Landsat8 satellites.
More precisely, the package provides the following tools:

- `eo_forge.io`: Provides generic classes to read and preprocess raw data. 
- `eo_forge.utils`: Helper utilities to download, calibrate, and extract patches from raw data.

Check the `project documentation <https://eo-forge.readthedocs.io/en/latest/>`_
for a full description of the tools included in the EO-Forge library.

Installation
============

You can install them from PyPI by simply running::

    pip install eo_forge

Installation from sources
-------------------------

To install the package, from the project root run::

    pip install .     # Regular installation
    pip install -e .  # Install in development mode


